/*****************************************************
Name:
   PROPLONG.C, Listing 2
File Type:
   Library
Description:
   Library file for managing long window properties.
   Analogous to the standard Windows functions
   GetProp, RemoveProp and SetProp, except they work
   on long properties.
Function List
   GetPropLong
   RemovePropLong
   SetPropLong
Portability:
   MS Windows 3.1, MSC, BC
*****************************************************/

/* MS - Windows */
#include <windows.h>

/* Own */
#include <proplong.h>

/*****************************************************
Function Name:
   GetPropLong
Parameters:
   hWnd - window handle
   PropId
Return:
   long property
Description:
   Retrives a long property previously set with the
   function SetPropLong.
*****************************************************/
LONG GetPropLong( HWND hWnd, int PropId )
   {

   return ( MAKELONG( GetProp( hWnd,
         MAKEINTRESOURCE( PropId )),
         GetProp( hWnd,
         MAKEINTRESOURCE( PropId + 1 ))));

   }   /* function GetPropLong */


/*****************************************************
Function Name:
   RemovePropLong
Parameters:
   hWnd - window handle
   PropId - property id
Return:
   long property
Description:
   Removes a long property previously set with the
   function SetPropLong.
*****************************************************/
LONG RemovePropLong( HWND hWnd, int PropId )
   {

   return ( MAKELONG( RemoveProp( hWnd,
         MAKEINTRESOURCE( PropId )),
         RemoveProp( hWnd,
         MAKEINTRESOURCE( PropId + 1 ))));

   }   /* function RemovePropLong */


/*****************************************************
Function Name:
   SetPropLong
Parameters:
   hWnd - window handle
   PropId - property id
   lProp - long property
Return:
   TRUE (SUCCESS) FASLE (FAIL)
Description:
   Associates a long property with a window.
*****************************************************/
BOOL SetPropLong( HWND hWnd, int PropId, LONG lProp )
   {

   if ( SetProp( hWnd, MAKEINTRESOURCE( PropId ),
         LOWORD( lProp )))
      {
      if ( SetProp( hWnd,
            MAKEINTRESOURCE( PropId + 1 ),
            HIWORD( lProp )))
         {
         return ( TRUE );
         }
      RemoveProp( hWnd, MAKEINTRESOURCE( PropId ));
      }

   return ( FALSE );

   }   /* function SetPropLong */

/* End of PROPLONG.C */
